@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -192,7 +192,7 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
             QListWidgetItem *item = new QListWidgetItem(items.at(i), completionBox);
             if (!items.at(i).startsWith(s_completionItemIndentString)) {
                 item->setFlags(item->flags() & ~Qt::ItemIsSelectable);
-                item->setBackgroundColor(AddresseeLineEditManager::self()->alternateColor());
+                item->setBackground(AddresseeLineEditManager::self()->alternateColor());
             }
             completionBox->addItem(item);
         }
