@@ -6,7 +6,8 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -53,11 +54,10 @@ class KPIM::CompletionOrderEditorPrivate
 {
 public:
     CompletionOrderEditorPrivate()
-        : mCompletionOrderWidget(nullptr)
     {
     }
 
-    CompletionOrderWidget *mCompletionOrderWidget;
+    CompletionOrderWidget *mCompletionOrderWidget = nullptr;
 };
 
 CompletionOrderEditor::CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch, QWidget *parent)
