@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -93,13 +93,13 @@ private:
     void slotItemChanged();
 
     KConfig mConfig;
-    QTreeWidget *mListView;
-    QPushButton *mUpButton;
-    QPushButton *mDownButton;
-    QAbstractItemModel *mCollectionModel;
-    KLDAP::LdapClientSearch *mLdapSearch;
+    QTreeWidget *mListView = nullptr;
+    QPushButton *mUpButton = nullptr;
+    QPushButton *mDownButton = nullptr;
+    QAbstractItemModel *mCollectionModel = nullptr;
+    KLDAP::LdapClientSearch *mLdapSearch = nullptr;
 
-    bool mDirty;
+    bool mDirty = false;
 };
 }
 
